Enum rtlola_parser::ast::BinOp[][src]

pub enum BinOp {
Show variants Add, Sub, Mul, Div, Rem, Pow, And, Or, BitXor, BitAnd, BitOr, Shl, Shr, Eq, Lt, Le, Ne, Ge, Gt,
}
An Ast node representing a binary operator.

Variants

Add

The + operator (addition)

Sub

The - operator (subtraction)

Mul

The * operator (multiplication)

Div

The / operator (division)

Rem

The % operator (modulus)

Pow

The ** operator (power)

And

The && operator (logical and)

Or

The || operator (logical or)

BitXor

The ^ operator (bitwise xor)

BitAnd

The & operator (bitwise and)

BitOr

The | operator (bitwise or)

Shl

The << operator (shift left)

Shr

The >> operator (shift right)

Eq

The == operator (equality)

Lt

The < operator (less than)

Le

The <= operator (less than or equal to)

Ne

The != operator (not equal to)

Ge

The >= operator (greater than or equal to)

Gt

The > operator (greater than)