Struct rtlola_parser::ast::ActivationCondition [−][src]
pub struct ActivationCondition {
pub expr: Option<Expression>,
pub id: NodeId,
pub span: Span,
}Expand description
An Ast node representing the declaration of a activation condition of a stream.
Fields
expr: Option<Expression>The boolean expression representing the activation condition. For periodic streams this component is assigned to ‘None’
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the activation condition