Struct rtlola_parser::ast::CloseSpec [−][src]
pub struct CloseSpec {
pub target: Expression,
pub id: NodeId,
pub span: Span,
}Expand description
An Ast node representing the declaration of a close condition of a stream template
Fields
target: ExpressionThe boolean expression defining the condition, if a stream instance is closed.
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the extend declaration