Struct rtlola_parser::ast::Constant [−][src]
pub struct Constant {
pub name: Ident,
pub ty: Option<Type>,
pub literal: Literal,
pub id: NodeId,
pub span: Span,
}Expand description
An Ast node representing the declaration of a constant.
Fields
name: IdentThe name of the constant stream
ty: Option<Type>The value type of the constant stream
literal: LiteralThe literal defining the constant
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the constant stream