Struct rtlola_parser::ast::FilterSpec [−][src]
pub struct FilterSpec {
pub target: Expression,
pub id: NodeId,
pub span: Span,
}Expand description
An Ast node representing the declaration of a filter condition of a stream template
Fields
target: ExpressionThe boolean expression defining the condition, if a stream instance is evaluated.
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the extend declaration