Struct rtlola_parser::ast::FunctionName [−][src]
An Ast node representing the name of a called function and also the names of the arguments.
Fields
name: IdentThe name of the function
arg_names: Vec<Option<Ident>>A list containing the name of each argument. If the argument is unnamed, it is represented by None.