Struct rtlola_parser::ast::Import [−][src]
An Ast node representing the import of a module, which brings additional implemented functionality to a specification. The ‘math’ module, for example, adds pre-defined mathematical functions as the sine or cosine function.
Fields
name: IdentThe name of the module
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the module