Struct rtlola_parser::ast::Input[][src]

pub struct Input {
    pub name: Ident,
    pub ty: Type,
    pub params: Vec<Rc<Parameter>>,
    pub id: NodeId,
    pub span: Span,
}
An Ast node representing the declaration of an input stream.

Fields

name: Ident

The name of the input stream

ty: Type

The value type of the input stream

params: Vec<Rc<Parameter>>

The parameters of a parameterized input stream; The vector is empty in non-parametrized streams.

id: NodeId

The id of the node in the Ast

span: Span

The span in the specification declaring the input stream