Struct rtlola_parser::ast::Literal[][src]

pub struct Literal {
    pub kind: LitKind,
    pub id: NodeId,
    pub span: Span,
}
An Ast node representing the declaration of a literal

Fields

kind: LitKind

The kind of the literal, e.g., boolean, string, numeric, …

id: NodeId

The id of the node in the Ast

span: Span

The span in the specification declaring the extend declaration