Struct rtlola_parser::ast::Parameter [−][src]
pub struct Parameter {
pub name: Ident,
pub ty: Option<Type>,
pub param_idx: usize,
pub id: NodeId,
pub span: Span,
}Expand description
An Ast node representing the declaration of a parameter of a parametrized stream.
Fields
name: IdentThe name of the parameter
ty: Option<Type>An optional value type annotation of the parameter
param_idx: usizeThe index of this parameter in the list of parameter of the respective output stream
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the parameter