Struct rtlola_parser::ast::Parenthesis
source · [−]Expand description
An Ast node representing an opening or closing parenthesis.
Fields
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the extend declaration