Struct rtlola_parser::ast::Type [−][src]
An Ast node representing the declaration of a value type
Fields
kind: TypeKindThe kind of the type, e.g., a tuple
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the extend declaration