Struct rtlola_parser::ast::TypeDeclField
source · [−]Expand description
An Ast node representing the declaration of a field of a user-defined type.
Fields
ty: TypeThe type of a field of a user-defined type
name: StringThe name of a field of a user-defined type
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the type declaration