Struct rtlola_parser::ast::TypeDeclaration [−][src]
pub struct TypeDeclaration {
pub name: Option<Ident>,
pub fields: Vec<Box<TypeDeclField>>,
pub id: NodeId,
pub span: Span,
}Expand description
An Ast node representing the declaration of a user-defined type.
Fields
name: Option<Ident>The name of the new type.
fields: Vec<Box<TypeDeclField>>The components of the new type, e.g. a GPS type might consist of a type for the latitude and for the longitude
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the type declaration