Struct rtlola_parser::ParserConfig [−][src]
pub struct ParserConfig { /* fields omitted */ }Expand description
The configuration of the parser.
Implementations
impl ParserConfig[src]
impl ParserConfig[src]pub fn from_path(path_to_spec: PathBuf) -> Result<Self>[src]
pub fn from_path(path_to_spec: PathBuf) -> Result<Self>[src]Reads the specification from the given path and creates a new parser configuration for it.
pub fn for_string(spec: String) -> Self[src]
pub fn for_string(spec: String) -> Self[src]Creates a new parser configuration for the given specification.