Struct rtlola_parser::ast::Input [−][src]
pub struct Input {
pub name: Ident,
pub ty: Type,
pub params: Vec<Rc<Parameter>>,
pub id: NodeId,
pub span: Span,
}Expand description
An Ast node representing the declaration of an input stream.
Fields
name: IdentThe name of the input stream
ty: TypeThe value type of the input stream
params: Vec<Rc<Parameter>>The parameters of a parameterized input stream; The vector is empty in non-parametrized streams.
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the input stream