Struct rtlola_parser::ast::Literal [−][src]
An Ast node representing the declaration of a literal
Fields
kind: LitKindThe kind of the literal, e.g., boolean, string, numeric, …
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the extend declaration