Struct rtlola_parser::ast::Output [−][src]
pub struct Output {
pub name: Ident,
pub ty: Option<Type>,
pub extend: ActivationCondition,
pub params: Vec<Rc<Parameter>>,
pub spawn: Option<SpawnSpec>,
pub filter: Option<FilterSpec>,
pub close: Option<CloseSpec>,
pub expression: Expression,
pub id: NodeId,
pub span: Span,
}Expand description
An Ast node representing the declaration of an output stream.
Fields
name: IdentThe name of the output stream
ty: Option<Type>An optional value type annotation of the output stream
extend: ActivationConditionThe activation condition, which defines when a new value of a stream is computed.
params: Vec<Rc<Parameter>>The parameters of a parameterized output stream; The vector is empty in non-parametrized streams
spawn: Option<SpawnSpec>The spawn declaration of a parameterized stream
filter: Option<FilterSpec>The filter declaration of a parameterized stream
close: Option<CloseSpec>The close declaration of parametrized stream
expression: ExpressionThe stream expression of a output stream, e.g., a + b.offset(by: -1).defaults(to: 0)
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the output stream