Struct rtlola_parser::ast::SpawnSpec
source · [−]pub struct SpawnSpec {
pub target: Option<Expression>,
pub annotated_pacing: Option<Expression>,
pub condition: Option<Expression>,
pub is_if: bool,
pub id: NodeId,
pub span: Span,
}Expand description
An Ast node representing the declaration of a spawn condition of a stream template.
Fields
target: Option<Expression>The expression defining the parameter instances. If the stream has more than one parameter, the expression needs to return a tuple, with one element for each parameter
annotated_pacing: Option<Expression>The pacing type describing when a new instance is created.
condition: Option<Expression>An additional condition for the creation of an instance, i.e., an instance is only created if the condition is true.
is_if: boolA flag to describe if the condition is an if or an unless condition.
id: NodeIdThe id of the node in the Ast
span: SpanThe span in the specification declaring the invoke declaration